# NetIF
Network interface library code used by HELICS for getting network addresses on a system without relying on name lookups. Header-only, requires C++14.

OS              | CPU Arch      | Status
--------------- | ------------- | -------------
FreeBSD         | x86_64        | [![Build Status](http://api.cirrus-ci.com/github/GMLC-TDC/netif.svg)](https://cirrus-ci.com/github/GMLC-TDC/netif)
Linux (Alpine)  | ARM/AArch64   | [![Build Status](https://cloud.drone.io/api/badges/GMLC-TDC/netif/status.svg)](https://cloud.drone.io/GMLC-TDC/netif)
Linux (Ubuntu)  | x86_64        | [![Build Status](https://dev.azure.com/HELICS-test/netif/_apis/build/status/GMLC-TDC.netif?branchName=master)](https://dev.azure.com/HELICS-test/netif/_build/latest?definitionId=1&branchName=master)
macOS 10.14     | x86_64        | [![Build Status](https://dev.azure.com/HELICS-test/netif/_apis/build/status/GMLC-TDC.netif?branchName=master)](https://dev.azure.com/HELICS-test/netif/_build/latest?definitionId=1&branchName=master)
Windows 10      | x86_64        | [![Build Status](https://dev.azure.com/HELICS-test/netif/_apis/build/status/GMLC-TDC.netif?branchName=master)](https://dev.azure.com/HELICS-test/netif/_build/latest?definitionId=1&branchName=master)


## Release
NetIF is distributed under the terms of the BSD-3 clause license. All new
contributions must be made under this license. [LICENSE](LICENSE)

SPDX-License-Identifier: BSD-3-Clause

Portions of the code written by LLNL with release number LLNL-CODE-739319
